==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QToolTip_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qtooltip.h>
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtWidgets/qwidget.h>
#include <QtCore/qrect.h>
#include <QtGui/qpalette.h>
#include <QtGui/qfont.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QToolTip(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolTip")
    QToolTip *_ptr = reinterpret_cast<QToolTip *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QToolTip::font()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_font__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::font()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QFont __qt_return_value = QToolTip::font();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::hideText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_hideText__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::hideText()")
    QTJAMBI_TRY {
        QToolTip::hideText();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::isVisible()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_isVisible__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::isVisible()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QToolTip::isVisible();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::palette()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_palette__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::palette()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QPalette __qt_return_value = QToolTip::palette();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::setFont(QFont)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_setFont_1native_1cref_1QFont__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::setFont(QFont)")
    QTJAMBI_TRY {
        const QFont& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QFont>(arg__1);
        QToolTip::setFont(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::setPalette(QPalette)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_setPalette_1native_1cref_1QPalette__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::setPalette(QPalette)")
    QTJAMBI_TRY {
        const QPalette& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QPalette>(arg__1);
        QToolTip::setPalette(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::showText(QPoint,QString,QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr__JLjava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::showText(QPoint,QString,QWidget*)")
    QTJAMBI_TRY {
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString >(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        QToolTip::showText(__qt_pos0, __qt_text1, __qt_w2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::showText(QPoint,QString,QWidget*,QRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr_1cref_1QRect__JLjava_lang_String_2JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2,
 QtJambiNativeID rect3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::showText(QPoint,QString,QWidget*,QRect)")
    QTJAMBI_TRY {
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString >(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        const QRect& __qt_rect3 = QtJambiAPI::valueReferenceFromNativeId<QRect>(rect3);
        QToolTip::showText(__qt_pos0, __qt_text1, __qt_w2, __qt_rect3);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::showText(QPoint,QString,QWidget*,QRect,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr_1cref_1QRect_1int__JLjava_lang_String_2JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2,
 QtJambiNativeID rect3,
 jint msecShowTime4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::showText(QPoint,QString,QWidget*,QRect,int)")
    QTJAMBI_TRY {
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString >(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        const QRect& __qt_rect3 = QtJambiAPI::valueReferenceFromNativeId<QRect>(rect3);
        QToolTip::showText(__qt_pos0, __qt_text1, __qt_w2, __qt_rect3, static_cast<int>(msecShowTime4));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::text()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_text__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::text()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QString __qt_return_value = QToolTip::text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QToolTip(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QToolTip>("QToolTip", "io/qt/widgets/QToolTip");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolTip);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QToolTip_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtwidgets-config.h>
#if QT_CONFIG(tooltip)
#include <QtWidgets/qtooltip.h>
#endif //QT_CONFIG(tooltip)
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtGui/qfont.h>
#include <QtGui/qpalette.h>
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(tooltip)


void deleter_QToolTip(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolTip")
    QToolTip *_ptr = reinterpret_cast<QToolTip *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(tooltip)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QToolTip::font()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_font__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::font()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        QFont __qt_return_value = QToolTip::font();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::hideText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_hideText__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::hideText()")
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        QToolTip::hideText();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::isVisible()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_isVisible__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::isVisible()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        __java_return_value = QToolTip::isVisible();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::palette()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_palette__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::palette()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        QPalette __qt_return_value = QToolTip::palette();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolTip::setFont(QFont)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_setFont_1native_1cref_1QFont__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::setFont(QFont)")
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        const QFont& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QFont>(arg__1);
        QToolTip::setFont(__qt_arg__1);
#else
        Q_UNUSED(arg__1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::setPalette(QPalette)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_setPalette_1native_1cref_1QPalette__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::setPalette(QPalette)")
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        const QPalette& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QPalette>(arg__1);
        QToolTip::setPalette(__qt_arg__1);
#else
        Q_UNUSED(arg__1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::showText(QPoint,QString,QWidget*,QRect,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr_1cref_1QRect_1int__JLjava_lang_String_2JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2,
 QtJambiNativeID rect3,
 jint msecShowTime4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::showText(QPoint,QString,QWidget*,QRect,int)")
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString>(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        const QRect& __qt_rect3 = QtJambiAPI::valueReferenceFromNativeId<QRect>(rect3);
        QToolTip::showText(__qt_pos0, __qt_text1, __qt_w2, __qt_rect3, static_cast<int>(msecShowTime4));
#else
        Q_UNUSED(pos0)
        Q_UNUSED(text1)
        Q_UNUSED(w2)
        Q_UNUSED(rect3)
        Q_UNUSED(msecShowTime4)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolTip::text()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolTip_text__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolTip::text()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(tooltip)
        QString __qt_return_value = QToolTip::text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(tooltip)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QToolTip(){
    using namespace RegistryAPI;

#if QT_CONFIG(tooltip)

    const std::type_info& typeId = registerObjectTypeInfo<QToolTip>("QToolTip", "io/qt/widgets/QToolTip");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolTip);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(tooltip)

}
